@@ -1,4 +1,4 @@
-# Copyright 2017-2023 QuantRocket LLC - All Rights Reserved
+# Copyright 2017-2024 QuantRocket LLC - All Rights Reserved
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -36,12 +36,12 @@ MOONSHOT_INTRADAY_AGGREGATE_RESULTS = {
         ('AbsWeight', '2018-12-19', '09:00:00'): 1.0,
         ('AbsWeight', '2018-12-19', '10:00:00'): 1.0,
         ('AbsWeight', '2018-12-19', '11:00:00'): 0.0,
-        ('Benchmark', '2018-12-18', '09:00:00'): 1.136,
-        ('Benchmark', '2018-12-18', '10:00:00'): 1.136465,
-        ('Benchmark', '2018-12-18', '11:00:00'): 1.13606,
-        ('Benchmark', '2018-12-19', '09:00:00'): 1.142945,
-        ('Benchmark', '2018-12-19', '10:00:00'): 1.142125,
-        ('Benchmark', '2018-12-19', '11:00:00'): 1.142185,
+        ('Benchmark', '2018-12-18', '09:00:00'): 0.0,
+        ('Benchmark', '2018-12-18', '10:00:00'): 0.0004093,
+        ('Benchmark', '2018-12-18', '11:00:00'): -0.0003564,
+        ('Benchmark', '2018-12-19', '09:00:00'): 0.0060604,
+        ('Benchmark', '2018-12-19', '10:00:00'): -0.0007174,
+        ('Benchmark', '2018-12-19', '11:00:00'): 5.25e-05,
         ('Commission', '2018-12-18', '09:00:00'): 0.0,
         ('Commission', '2018-12-18', '10:00:00'): 0.0002,
         ('Commission', '2018-12-18', '11:00:00'): 0.00002,
@@ -94,12 +94,12 @@ MOONSHOT_INTRADAY_DETAILED_RESULTS = {
         ('AbsWeight', '2018-12-19', '09:00:00'): 0.2,
         ('AbsWeight', '2018-12-19', '10:00:00'): 0.2,
         ('AbsWeight', '2018-12-19', '11:00:00'): 0.2,
-        ('Benchmark', '2018-12-18', '09:00:00'): 1.136,
-        ('Benchmark', '2018-12-18', '10:00:00'): 1.136465,
-        ('Benchmark', '2018-12-18', '11:00:00'): 1.13606,
-        ('Benchmark', '2018-12-19', '09:00:00'): 1.142945,
-        ('Benchmark', '2018-12-19', '10:00:00'): 1.142125,
-        ('Benchmark', '2018-12-19', '11:00:00'): 1.142185,
+        ('Benchmark', '2018-12-18', '09:00:00'): 0.0,
+        ('Benchmark', '2018-12-18', '10:00:00'): 0.0004093,
+        ('Benchmark', '2018-12-18', '11:00:00'): -0.0003564,
+        ('Benchmark', '2018-12-19', '09:00:00'): 0.0060604,
+        ('Benchmark', '2018-12-19', '10:00:00'): -0.0007174,
+        ('Benchmark', '2018-12-19', '11:00:00'): 5.25e-05,
         ('Commission', '2018-12-18', '09:00:00'): 0.0,
         ('Commission', '2018-12-18', '10:00:00'): 0.0,
         ('Commission', '2018-12-18', '11:00:00'): 0.00001,
@@ -688,7 +688,7 @@ class IntradayToDailyTestCase(unittest.TestCase):
         daily_results = intraday_to_daily(intraday_results)
 
         daily_results = daily_results.reset_index()
-        daily_results.loc[:, "Date"] = daily_results.Date.dt.strftime("%Y-%m-%d")
+        daily_results["Date"] = daily_results.Date.dt.strftime("%Y-%m-%d")
         daily_results = daily_results.set_index(["Field", "Date"])
 
         self.assertDictEqual(
@@ -700,9 +700,9 @@ class IntradayToDailyTestCase(unittest.TestCase):
                 # max
                 ('AbsWeight', '2018-12-18'): 0.0,
                 ('AbsWeight', '2018-12-19'): 1.0,
-                # last
-                ('Benchmark', '2018-12-18'): 1.13606,
-                ('Benchmark', '2018-12-19'): 1.142185,
+                # sum
+                ('Benchmark', '2018-12-18'): 0.000053,
+                ('Benchmark', '2018-12-19'): 0.005395,
                 # sum
                 ('Commission', '2018-12-18'): 0.00022,
                 ('Commission', '2018-12-19'): 0.0001,
@@ -734,7 +734,7 @@ class IntradayToDailyTestCase(unittest.TestCase):
         daily_results = intraday_to_daily(intraday_results)
 
         daily_results = daily_results.reset_index()
-        daily_results.loc[:, "Date"] = daily_results.Date.dt.strftime("%Y-%m-%d")
+        daily_results["Date"] = daily_results.Date.dt.strftime("%Y-%m-%d")
         daily_results = daily_results.set_index(["Field", "Date"])
 
         daily_results = daily_results.where(daily_results.notnull(), None)
@@ -749,9 +749,9 @@ class IntradayToDailyTestCase(unittest.TestCase):
                                    # max
                                    ('AbsWeight', '2018-12-18'): 0.0,
                                    ('AbsWeight', '2018-12-19'): 0.2,
-                                   # last
-                                   ('Benchmark', '2018-12-18'): 1.13606,
-                                   ('Benchmark', '2018-12-19'): 1.142185,
+                                   # sum
+                                   ('Benchmark', '2018-12-18'): 0.000053,
+                                   ('Benchmark', '2018-12-19'): 0.005395,
                                    # sum
                                    ('Commission', '2018-12-18'): 1e-05,
                                    ('Commission', '2018-12-19'): 2e-05,
@@ -779,9 +779,9 @@ class IntradayToDailyTestCase(unittest.TestCase):
                                    # max
                                    ('AbsWeight', '2018-12-18'): 0.0,
                                    ('AbsWeight', '2018-12-19'): 0.2,
-                                   # last
-                                   ('Benchmark', '2018-12-18'): 'nan',
-                                   ('Benchmark', '2018-12-19'): 'nan',
+                                   # sum
+                                   ('Benchmark', '2018-12-18'): 0.0,
+                                   ('Benchmark', '2018-12-19'): 0.0,
                                    # sum
                                    ('Commission', '2018-12-18'): 0.0,
                                    ('Commission', '2018-12-19'): 3e-05,
@@ -816,7 +816,7 @@ class IntradayToDailyTestCase(unittest.TestCase):
         daily_results = intraday_to_daily(intraday_results)
 
         daily_results = daily_results.reset_index()
-        daily_results.loc[:, "Date"] = daily_results.Date.dt.strftime("%Y-%m-%d")
+        daily_results["Date"] = daily_results.Date.dt.strftime("%Y-%m-%d")
         daily_results = daily_results.set_index(["Field", "Date"])
 
         self.maxDiff = None
@@ -863,7 +863,7 @@ class IntradayToDailyTestCase(unittest.TestCase):
         daily_results = intraday_to_daily(intraday_results)
 
         daily_results = daily_results.reset_index()
-        daily_results.loc[:, "Date"] = daily_results.Date.dt.strftime("%Y-%m-%d")
+        daily_results["Date"] = daily_results.Date.dt.strftime("%Y-%m-%d")
         daily_results = daily_results.set_index(["Field", "Date"])
 
         daily_results = daily_results.where(daily_results.notnull(), None)
@@ -963,7 +963,7 @@ class IntradayToDailyTestCase(unittest.TestCase):
                                           })
 
         daily_results = daily_results.reset_index()
-        daily_results.loc[:, "Date"] = daily_results.Date.dt.strftime("%Y-%m-%d")
+        daily_results["Date"] = daily_results.Date.dt.strftime("%Y-%m-%d")
         daily_results = daily_results.set_index(["Field", "Date"])
 
         daily_results = daily_results.where(daily_results.notnull(), None)
