@@ -1,4 +1,4 @@
-# Copyright 2017-2023 QuantRocket LLC - All Rights Reserved
+# Copyright 2017-2024 QuantRocket LLC - All Rights Reserved
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -492,7 +492,7 @@ def intraday_to_daily(
 
     AbsExposure: max
     AbsWeight: max
-    Benchmark: last
+    Benchmark: sum
     Commission: sum
     CommissionAmount: sum
     NetExposure: extreme
@@ -542,7 +542,7 @@ def intraday_to_daily(
     field_hows = {
         'AbsExposure': 'max',
         'AbsWeight': 'max',
-        'Benchmark': 'last',
+        'Benchmark': 'sum',
         'Commission': 'sum',
         'CommissionAmount': 'sum',
         'NetExposure': 'extreme',
